from pyduinocli.commands.arduino import ArduinoCliCommand as Arduino
from pyduinocli.errors.arduinoerror import ArduinoError
